@@ -86,7 +86,7 @@ dialog_button_clicked_cb (GtkDialog *dialog, gint response_id)
 		gdk_spawn_command_line_on_screen (screen, command, &error);
 		if (error != NULL)
 		{
-			g_warning (error->message);
+			g_warning ("%s", error->message);
 			g_error_free (error);
 		}
 		g_free (command);
@@ -541,7 +541,7 @@ setup_dialog (GladeXML *dialog)
 	
 	/* first pane */
 	check = WID ("touchpad_check");
-	g_signal_connect (G_OBJECT (check), "toggled",
+	g_signal_connect (check, "toggled",
 			  G_CALLBACK (cb_touchpad_toggled), dialog);
 	value = g_synaptics_is_enabled (synaptics);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check),
@@ -552,12 +552,12 @@ setup_dialog (GladeXML *dialog)
 	if (num == 0)
 		num = g_synaptics_sensitivity (synaptics);
 	gtk_range_set_value (GTK_RANGE (scale), num);
-	g_signal_connect (G_OBJECT (scale), "change-value",
+	g_signal_connect (scale, "change-value",
 			  G_CALLBACK (cb_sensitivity_change), dialog);
 
 	/* second pane (tapping) */
 	check = WID ("faster_tapping_check");
-	g_signal_connect (G_OBJECT (check), "toggled",
+	g_signal_connect (check, "toggled",
 			  G_CALLBACK (cb_fast_taps_toggled), dialog);
 	value = g_synaptics_are_fast_taps_enabled (synaptics);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check),
@@ -566,11 +566,11 @@ setup_dialog (GladeXML *dialog)
 	scale = WID ("tapping_time_scale");
 	num = g_synaptics_tap_time (synaptics);
 	gtk_range_set_value (GTK_RANGE (scale), num);
-	g_signal_connect (G_OBJECT (scale), "change-value",
+	g_signal_connect (scale, "change-value",
 			  G_CALLBACK (cb_tap_time_change), dialog);
 
 	check = WID ("tapping_check");
-	g_signal_connect (G_OBJECT (check), "toggled",
+	g_signal_connect (check, "toggled",
 			  G_CALLBACK (cb_tapping_toggled), dialog);
 	value = g_synaptics_is_tapping_enabled (synaptics);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check),
@@ -580,12 +580,12 @@ setup_dialog (GladeXML *dialog)
 	scale = WID ("vertical_scroll_scale");
 	num = g_synaptics_vertical_scroll_delta (synaptics);
 	gtk_range_set_value (GTK_RANGE (scale), num * -1);
-	g_signal_connect (G_OBJECT (scale), "change-value",
+	g_signal_connect (scale, "change-value",
 			  G_CALLBACK (cb_vertical_scroll_change), dialog);
 
 	check = WID ("vertical_scroll_check");
 	value = g_synaptics_is_vertical_scroll_enabled (synaptics);
-	g_signal_connect (G_OBJECT (check), "toggled",
+	g_signal_connect (check, "toggled",
 			  G_CALLBACK (cb_vertical_scroll_toggled), dialog);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check),
 	    			      value);
@@ -593,12 +593,12 @@ setup_dialog (GladeXML *dialog)
 	scale = WID ("horizontal_scroll_scale");
 	num = g_synaptics_horizontal_scroll_delta (synaptics);
 	gtk_range_set_value (GTK_RANGE (scale), num * -1);
-	g_signal_connect (G_OBJECT (scale), "change-value",
+	g_signal_connect (scale, "change-value",
 			  G_CALLBACK (cb_horizontal_scroll_change), dialog);
 
 	check = WID ("horizontal_scroll_check");
 	value = g_synaptics_is_horizontal_scroll_enabled (synaptics);
-	g_signal_connect (G_OBJECT (check), "toggled",
+	g_signal_connect (check, "toggled",
 			  G_CALLBACK (cb_horizontal_scroll_toggled), dialog);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check),
 	    			      value);
@@ -606,43 +606,43 @@ setup_dialog (GladeXML *dialog)
 	scale = WID ("circular_scroll_scale");
 	num = g_synaptics_circular_scroll_delta (synaptics);
 	gtk_range_set_value (GTK_RANGE (scale), num * -1);
-	g_signal_connect (G_OBJECT (scale), "change-value",
+	g_signal_connect (scale, "change-value",
 			  G_CALLBACK (cb_circular_scroll_change), dialog);
 
 	check = WID ("circular_scroll_check");
 	value = g_synaptics_is_circular_scroll_enabled (synaptics);
-	g_signal_connect (G_OBJECT (check), "toggled",
+	g_signal_connect (check, "toggled",
 			  G_CALLBACK (cb_circular_scroll_toggled), dialog);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check),
 	    			      value);
 
 	button = WID ("trigger_top_edge_toggle");
-	g_signal_connect (G_OBJECT (button), "button_press_event",
+	g_signal_connect (button, "button_press_event",
 			  G_CALLBACK (cb_trigger_top_pressed),dialog);
 	button = WID ("trigger_bottom_edge_toggle");
-	g_signal_connect (G_OBJECT (button), "button_press_event",
+	g_signal_connect (button, "button_press_event",
 			  G_CALLBACK (cb_trigger_bottom_pressed),dialog);
 	button = WID ("trigger_left_edge_toggle");
-	g_signal_connect (G_OBJECT (button), "button_press_event",
+	g_signal_connect (button, "button_press_event",
 			  G_CALLBACK (cb_trigger_left_pressed),dialog);
 	button = WID ("trigger_right_edge_toggle");
-	g_signal_connect (G_OBJECT (button), "button_press_event",
+	g_signal_connect (button, "button_press_event",
 			  G_CALLBACK (cb_trigger_right_pressed),dialog);
 
 	button = WID ("trigger_top_left_corner_toggle");
-	g_signal_connect (G_OBJECT (button), "button_press_event",
+	g_signal_connect (button, "button_press_event",
 			  G_CALLBACK (cb_trigger_top_left_pressed),dialog);
 	button = WID ("trigger_top_right_corner_toggle");
-	g_signal_connect (G_OBJECT (button), "button_press_event",
+	g_signal_connect (button, "button_press_event",
 			  G_CALLBACK (cb_trigger_top_right_pressed),dialog);
 	button = WID ("trigger_bottom_left_corner_toggle");
-	g_signal_connect (G_OBJECT (button), "button_press_event",
+	g_signal_connect (button, "button_press_event",
 			  G_CALLBACK (cb_trigger_bottom_left_pressed),dialog);
 	button = WID ("trigger_bottom_right_corner_toggle");
-	g_signal_connect (G_OBJECT (button), "button_press_event",
+	g_signal_connect (button, "button_press_event",
 			  G_CALLBACK (cb_trigger_bottom_right_pressed),dialog);
 	button = WID ("trigger_all_corners_button");
-	g_signal_connect (G_OBJECT (button), "clicked",
+	g_signal_connect (button, "clicked",
 			  G_CALLBACK (cb_trigger_all_clicked),dialog);
 	set_circular_scroll_trigger_state (dialog);
 
@@ -650,14 +650,14 @@ setup_dialog (GladeXML *dialog)
 	value = g_synaptics_is_coasting_enabled (synaptics);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check),
 	    			      value);
-	g_signal_connect (G_OBJECT (check), "toggled",
+	g_signal_connect (check, "toggled",
 			  G_CALLBACK (cb_continue_scrolling_toggled), dialog);
 
 	check = WID ("cursor_movement_check");
 	value = g_synaptics_is_edge_motion_enabled (synaptics);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check),
 	    			      value);
-	g_signal_connect (G_OBJECT (check), "toggled",
+	g_signal_connect (check, "toggled",
 			  G_CALLBACK (cb_cursor_movement_toggled), dialog);
 
 
@@ -665,32 +665,32 @@ setup_dialog (GladeXML *dialog)
 	scale = WID ("accel_factor_scale");
 	num = g_synaptics_accel_factor (synaptics);
 	gtk_range_set_value (GTK_RANGE (scale), num);
-	g_signal_connect (G_OBJECT (scale), "change-value",
+	g_signal_connect (scale, "change-value",
 			  G_CALLBACK (cb_accel_factor_change), dialog);
 
 	scale = WID ("min_speed_scale");
 	num = g_synaptics_min_speed (synaptics);
 	gtk_range_set_value (GTK_RANGE (scale), num);
-	g_signal_connect (G_OBJECT (scale), "change-value",
+	g_signal_connect (scale, "change-value",
 			  G_CALLBACK (cb_min_speed_change), dialog);
 
 	scale = WID ("max_speed_scale");
 	num = g_synaptics_max_speed (synaptics);
 	gtk_range_set_value (GTK_RANGE (scale), num);
-	g_signal_connect (G_OBJECT (scale), "change-value",
+	g_signal_connect (scale, "change-value",
 			  G_CALLBACK (cb_max_speed_change), dialog);
 
 			  
 	/* dialog window */
 	widget = WID ("gsynaptics_dialog");
-	g_signal_connect (G_OBJECT (widget), "response",
+	g_signal_connect (widget, "response",
 			  G_CALLBACK (dialog_button_clicked_cb), NULL);
 
 	/* gtk_window_set_resizable (GTK_WINDOW (widget), FALSE); */
 
 	gtk_window_set_default_size (GTK_WINDOW (widget), 400, -1);
 
-	path = g_build_filename (DATADIR "/pixmaps", "touchpad.png");
+	path = g_build_filename (DATADIR "/pixmaps", "touchpad.png", NULL);
 	if (path)
 	{
 		icon_pixbuf = gdk_pixbuf_new_from_file (path, NULL);
